Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1321)

Unified Diff: third_party/WebKit/Tools/Scripts/webkitpy/layout_tests/port/base.py

Issue 2455883004: Rename _webkit_baseline_path -> _absolute_baseline_path. (Closed)
Patch Set: Rename _webkit_baseline_path -> _absolute_baseline_path. Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | third_party/WebKit/Tools/Scripts/webkitpy/layout_tests/port/linux_unittest.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Tools/Scripts/webkitpy/layout_tests/port/base.py
diff --git a/third_party/WebKit/Tools/Scripts/webkitpy/layout_tests/port/base.py b/third_party/WebKit/Tools/Scripts/webkitpy/layout_tests/port/base.py
index ef63f815453df5842f08ccd5229dc922cd41ba83..db5290c411699767897d69c4115867e352f06667 100644
--- a/third_party/WebKit/Tools/Scripts/webkitpy/layout_tests/port/base.py
+++ b/third_party/WebKit/Tools/Scripts/webkitpy/layout_tests/port/base.py
@@ -305,7 +305,7 @@ class Port(object):
"""Return a list of absolute paths to directories to search under for
baselines. The directories are searched in order.
"""
- return map(self._webkit_baseline_path, self.FALLBACK_PATHS[self.version()])
+ return map(self._absolute_baseline_path, self.FALLBACK_PATHS[self.version()])
@memoized
def _compare_baseline(self):
@@ -954,7 +954,7 @@ class Port(object):
def _expectations_from_skipped_files(self, skipped_file_paths):
tests_to_skip = []
for search_path in skipped_file_paths:
- filename = self._filesystem.join(self._webkit_baseline_path(search_path), "Skipped")
+ filename = self._filesystem.join(self._absolute_baseline_path(search_path), "Skipped")
if not self._filesystem.exists(filename):
_log.debug("Skipped does not exist: %s", filename)
continue
@@ -1558,11 +1558,11 @@ class Port(object):
return path
return None
- def _webkit_baseline_path(self, platform):
- """Return the full path to the top of the baseline tree for a
- given platform.
+ def _absolute_baseline_path(self, platform_dir):
+ """Return the absolute path to the top of the baseline tree for a
+ given platform directory.
"""
- return self._filesystem.join(self.layout_tests_dir(), 'platform', platform)
+ return self._filesystem.join(self.layout_tests_dir(), 'platform', platform_dir)
def _driver_class(self):
"""Returns the port's driver implementation."""
« no previous file with comments | « no previous file | third_party/WebKit/Tools/Scripts/webkitpy/layout_tests/port/linux_unittest.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698